@@ -8,7 +8,9 @@ use LWP::UserAgent;
 use WebService::Solr::Response;
 use HTTP::Request;
 use HTTP::Headers;
-use XML::Generator;
+use XML::Easy::Element;
+use XML::Easy::Content;
+use XML::Easy::Text ();
 
 has 'url' => (
     is      => 'ro',
@@ -28,15 +30,7 @@ has 'default_params' => (
     default    => sub { { wt => 'json' } }
 );
 
-has '_xml_generator' => (
-    is       => 'ro',
-    init_arg => undef,
-    default  => sub {
-        XML::Generator->new( ':std', escape => 'always,even-entities' );
-    },
-);
-
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 sub BUILDARGS {
     my ( $self, $url, $options ) = @_;
@@ -58,17 +52,22 @@ sub add {
     my ( $self, $doc, $params ) = @_;
     my @docs = ref $doc eq 'ARRAY' ? @$doc : ( $doc );
 
+    my @elements = map {
+        (   '',
+            blessed $_
+            ? $_->to_element
+            : WebService::Solr::Document->new(
+                ref $_ eq 'HASH' ? %$_ : @$_
+                )->to_element
+            )
+    } @docs;
+
     $params ||= {};
-    my $xml = $self->_xml_generator->add(
-        $params,
-        map {
-            if ( blessed $_ ) { $_->to_xml }
-            else {
-                WebService::Solr::Document->new(
-                    ref $_ eq 'HASH' ? %$_ : @$_ )->to_xml;
-            }
-            } @docs
-    );
+    my $e
+        = XML::Easy::Element->new( 'add', $params,
+        XML::Easy::Content->new( [ @elements, '' ] ),
+        );
+    my $xml = XML::Easy::Text::xml10_write_element( $e );
 
     my $response = $self->_send_update( $xml );
     return $response->ok;
@@ -81,9 +80,9 @@ sub update {
 sub commit {
     my ( $self, $params ) = @_;
     $params ||= {};
-    my $response
-        = $self->_send_update( $self->_xml_generator->commit( $params ), {},
-        0 );
+    my $e        = XML::Easy::Element->new( 'commit', $params, [ '' ] );
+    my $xml      = XML::Easy::Text::xml10_write_element( $e );
+    my $response = $self->_send_update( $xml, {}, 0 );
     return $response->ok;
 }
 
@@ -96,19 +95,25 @@ sub rollback {
 sub optimize {
     my ( $self, $params ) = @_;
     $params ||= {};
-    my $gen = XML::Generator->new( ':std', escape => 'always,even-entities' );
-    my $response = $self->_send_update( $gen->optimize( $params ), {}, 0 );
+    my $e        = XML::Easy::Element->new( 'optimize', $params, [ '' ] );
+    my $xml      = XML::Easy::Text::xml10_write_element( $e );
+    my $response = $self->_send_update( $xml, {}, 0 );
     return $response->ok;
 }
 
 sub delete {
     my ( $self, $options ) = @_;
-    my $gen = $self->_xml_generator;
 
     my $xml = '';
     for my $k ( keys %$options ) {
         my $v = $options->{ $k };
-        $xml .= $gen->$k( $_ ) for ref $v ? @$v : $v;
+        $xml .= join(
+            '',
+            map {
+                XML::Easy::Text::xml10_write_element(
+                    XML::Easy::Element->new( $k, {}, [ $_ ] ) )
+                } ref $v ? @$v : $v
+        );
     }
 
     my $response = $self->_send_update( "<delete>${xml}</delete>" );
@@ -117,16 +122,12 @@ sub delete {
 
 sub delete_by_id {
     my ( $self, $id ) = @_;
-    my $response = $self->_send_update( "<delete><id>$id</id></delete>" );
-    return $response->ok;
+    return $self->delete( { id => $id } );
 }
 
 sub delete_by_query {
     my ( $self, $query ) = @_;
-    my $gen = $self->_xml_generator;
-    my $response
-        = $self->_send_update( $gen->delete( $gen->query( $query ) ) );
-    return $response->ok;
+    return $self->delete( { query => $query } );
 }
 
 sub ping {
